powered by
This function analyzes if a world provided by the user satisfies all requirements.
check_user_world(world)
The world provided by the user. It's a list. See details in generar_mundo.
generar_mundo
If a misespecification is found, this function produces a stop and provides a descriptive error message.
This function is called by generar_mundo.