powered by
This function produces the animation that shows all actions performed by Karel since its world was generated by generate_world.
generate_world
run_actions(loop = TRUE)
A logical value TRUE or FALSE indicating if the animation should repeat itself after finished or not (defaults to TRUE).
Produces an animation with gganimate.
gganimate
# NOT RUN { generate_world("mundo001") move() pick_beeper() turn_left() put_beeper() run_actions() # }
Run the code above in your browser using DataLab