This function takes a "world" (i.e. a list with data about its size, walls,
beepers and Karel's position and direction), plots it and prepares everything
so that Karel can start performing actions in it. It must be run always
before Karel starts working on her goals, especially if we have made a
mistake, we must start all over again by first running this function.