get_beepers_df_row: Get row number in beepers dataset
Description
Given current position of Karel, it calculates the cell id (cell) and
returns the row number of the respective cell in the beepers_now dataset.
It's used to add or remove beepers in this row when Karel picks or puts
beepers.