Helper function for generate_open_moves(). It takes the available data
for a piece of vertical wall (x and y coordinates of its beginning point and
its length) and produces a dataset with the positions and directions of
prohibited moves for Karel because of this wall.
put_ver_walls(x, y, lgth)y x and y coordinates of the beginning point of the wall
length of the wall
A lgth x 3 dataset with coordinates where Karel can't move and the direction (side) towards it can't move because of this piece of vertical wall.